# hbMEP

hbMEP is a Python library for hierarchical Bayesian estimation of motor-evoked potential (MEP) size recruitment curves.

[![Cite](https://img.shields.io/badge/stats.AP-arXiv:2407.08709-B31B1B.svg)](http://doi.org/10.48550/arXiv.2407.08709)
[![Docs](https://github.com/hbmep/hbmep/actions/workflows/documentation.yaml/badge.svg)](https://github.com/hbmep/hbmep/actions/workflows/documentation.yaml)
[![pages-build-deployment](https://github.com/hbmep/hbmep/actions/workflows/pages/pages-build-deployment/badge.svg)](https://github.com/hbmep/hbmep/actions/workflows/pages/pages-build-deployment)

## Documentation

Read the docs at [hbmep.github.io/hbmep/](https://hbmep.github.io/hbmep/)

## Citation

Please cite [Tyagi et al., 2024](https://arxiv.org/abs/2407.08709) if you find this code useful in your research. The BibTeX entry for the paper is:

```
@article{tyagi_hierarchical_2024,
    title = {Hierarchical {Bayesian} estimation of motor-evoked potential recruitment curves yields accurate and robust estimates},
    author = {Tyagi, Vishweshwar and Murray, Lynda M. and Asan, Ahmet S. and Mandigo, Christopher and Virk, Michael S. and Harel, Noam Y. and Carmel, Jason B. and McIntosh, James R.},
    journal={arXiv preprint arXiv:2407.08709},
    year = {2024},
    doi = {http://doi.org/10.48550/arXiv.2407.08709}
}
```

## License

hbMEP is free software made available under the MIT License. For details see
the LICENSE file.
